#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pattern-arrows
version:              0.0.2
visibility:           public
id:                   pattern-arrows-0.0.2-DW0EQtjIrhBGXfEHYuR7zB
key:                  pattern-arrows-0.0.2-DW0EQtjIrhBGXfEHYuR7zB
license:              MIT
copyright:            (c) Phil Freeman 2013
maintainer:           Phil Freeman <paf31@cantab.net>
author:               Phil Freeman <paf31@cantab.net>
stability:            experimental
homepage:
    http://blog.functorial.com/posts/2013-10-27-Pretty-Printing-Arrows.html

synopsis:             Arrows for Pretty Printing
description:
    A library for generating concise pretty printers based on precedence rules.

category:             Text, Combinators, Pretty Printer
abi:                  2079b2f07871f103a1c2b493ddc08587
exposed:              True
exposed-modules:      Control.PatternArrows
import-dirs:          /usr/lib/ghc-8.10.5/site-local/pattern-arrows-0.0.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/pattern-arrows-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/pattern-arrows-0.0.2
hs-libraries:         HSpattern-arrows-0.0.2-DW0EQtjIrhBGXfEHYuR7zB
depends:              base-4.14.2.0 mtl-2.2.2
haddock-interfaces:
    /usr/share/doc/haskell-pattern-arrows/html/pattern-arrows.haddock

haddock-html:         /usr/share/doc/haskell-pattern-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

